@@ -36,12 +36,12 @@ def parse_p12(p12_path, passphrase, directory):
     if not path.exists(directory):
         makedirs(directory)
 
-    private_key_file = directory + '/private_key.pem'
+    private_key_file = path.join(directory, '/private_key.pem')
     with open(private_key_file, 'w') as pk:
         pk.write(dump_privatekey(FILETYPE_PEM, private_key).decode("utf-8"))
 
-    cert_file = directory + '/cert.pem'
+    cert_file = path.join(directory, '/cert.pem')
     with open(cert_file, 'w') as cert:
         cert.write(dump_certificate(FILETYPE_PEM, certificate).decode("utf-8"))
 
-    print("Success!")
+    print("p12 extracted!")
