@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-#coding:utf8
+# coding:utf8
 
 """
 Send a SSL request to the SightCall authentification API, with the key 
@@ -9,12 +9,14 @@ and certificate extracted from a p12 file.
 
 from os import path, makedirs
 import urllib.request as request
-import http.client, json
+import http.client
+import json
 
 from sightcall_auth.config import directory as default_cert_dir
 
 __all__ = ['Auth']
 
+
 class HTTPSClientAuthHandler(request.HTTPSHandler):
 
     def __init__(self, key, cert):
@@ -29,10 +31,15 @@ class HTTPSClientAuthHandler(request.HTTPSHandler):
         return self.do_open(self.getConnection, req)
 
     def getConnection(self, host, timeout=300):
-        return http.client.HTTPSConnection(host, key_file=self.key, cert_file=self.cert)
+        return http.client.HTTPSConnection(
+            host,
+            key_file=self.key,
+            cert_file=self.cert
+        )
 
 
 class Auth():
+
     """
         :param client_id: The client ID of your provider
         :param client_secret: The client secret of your provider
@@ -45,17 +52,21 @@ class Auth():
     url = None
     directory = None
 
-    def __init__(self, client_id, client_secret, url, cert_directory=directory):
+    def __init__(self, client_id, client_secret, url,
+                 cert_directory=default_cert_dir
+                 ):
         self.client_id = client_id
         self.client_secret = client_secret
         self.url = url
         self.directory = cert_directory
 
     def connect(self, uid):
-        https_con = HTTPSClientAuthHandler(self.directory + '/private_key.pem', self.directory + '/cert.pem')
+        https_con = HTTPSClientAuthHandler(
+            os.path.join(self.directory, '/private_key.pem'),
+            os.path.join(self.directory, '/cert.pem')
+        )
         opener = request.build_opener(https_con)
-        response = opener.open(path.join(self.url, "?client_id="+ self.client_id
-                                            +"&client_secret="+ self.client_secret
-                                            +"&uid="+ uid))
+        url_params = "?client_id=%s&client_secret=%s&uid=%s" \
+            % self.client_id, self.client_secret, uid
+        response = opener.open(path.join(self.url,  url_params))
         return json.loads(response.read().decode("utf-8"))['token']
-
